pub(super) fn load_manifest(
location: &str,
) -> Result<ReleaseManifest, InstallerError>Expand description
Fetches and deserializes a release manifest from a URL or local path.
pub(super) fn load_manifest(
location: &str,
) -> Result<ReleaseManifest, InstallerError>Fetches and deserializes a release manifest from a URL or local path.